@@ -122,20 +122,20 @@ BOOL LASreadPoint::setup(U32 num_items, const LASitem* items, const LASzip* lasz
     switch (items[i].type)
     {
     case LASitem::POINT10:
-      if (IS_LITTLE_ENDIAN())
+      if (Endian::IS_LITTLE_ENDIAN)
         readers_raw[i] = new LASreadItemRaw_POINT10_LE();
       else
         readers_raw[i] = new LASreadItemRaw_POINT10_BE();
       break;
     case LASitem::GPSTIME11:
-      if (IS_LITTLE_ENDIAN())
+      if (Endian::IS_LITTLE_ENDIAN)
         readers_raw[i] = new LASreadItemRaw_GPSTIME11_LE();
       else
         readers_raw[i] = new LASreadItemRaw_GPSTIME11_BE();
        break;
     case LASitem::RGB12:
     case LASitem::RGB14:
-      if (IS_LITTLE_ENDIAN())
+      if (Endian::IS_LITTLE_ENDIAN)
         readers_raw[i] = new LASreadItemRaw_RGB12_LE();
       else
         readers_raw[i] = new LASreadItemRaw_RGB12_BE();
@@ -145,20 +145,20 @@ BOOL LASreadPoint::setup(U32 num_items, const LASitem* items, const LASzip* lasz
       readers_raw[i] = new LASreadItemRaw_BYTE(items[i].size);
       break;
     case LASitem::POINT14:
-      if (IS_LITTLE_ENDIAN())
+      if (Endian::IS_LITTLE_ENDIAN)
         readers_raw[i] = new LASreadItemRaw_POINT14_LE();
       else
         readers_raw[i] = new LASreadItemRaw_POINT14_BE();
       break;
     case LASitem::RGBNIR14:
-      if (IS_LITTLE_ENDIAN())
+      if (Endian::IS_LITTLE_ENDIAN)
         readers_raw[i] = new LASreadItemRaw_RGBNIR14_LE();
       else
         readers_raw[i] = new LASreadItemRaw_RGBNIR14_BE();
       break;
     case LASitem::WAVEPACKET13:
     case LASitem::WAVEPACKET14:
-      if (IS_LITTLE_ENDIAN())
+      if (Endian::IS_LITTLE_ENDIAN)
         readers_raw[i] = new LASreadItemRaw_WAVEPACKET13_LE();
       else
         readers_raw[i] = new LASreadItemRaw_WAVEPACKET13_BE();
@@ -438,7 +438,7 @@ BOOL LASreadPoint::read(U8* const * point)
           if (current_chunk >= number_chunks)
           {
             number_chunks += 256;
-            chunk_starts = (I64*)realloc(chunk_starts, sizeof(I64)*(number_chunks+1));
+            chunk_starts = (I64*)realloc_las(chunk_starts, sizeof(I64)*(number_chunks+1));
           }
           chunk_starts[tabled_chunks] = point_start; // needs fixing
           tabled_chunks++;
@@ -511,17 +511,17 @@ BOOL LASreadPoint::read(U8* const * point)
       // end-of-file
       if (dec)
       {
-        sprintf(last_error, "end-of-file during chunk with index %u", current_chunk);
+        snprintf(last_error, 128, "end-of-file during chunk with index %u", current_chunk);
       }
       else
       {
-        sprintf(last_error, "end-of-file");
+        snprintf(last_error, 128, "end-of-file");
       }
     }
     else
     {
       // decompression error
-      sprintf(last_error, "chunk with index %u of %u is corrupt", current_chunk, tabled_chunks);
+      snprintf(last_error, 128, "chunk with index %u of %u is corrupt", current_chunk, tabled_chunks);
       // if we know where the next chunk starts ...
       if ((current_chunk+1) < tabled_chunks)
       {
@@ -553,7 +553,7 @@ BOOL LASreadPoint::check_end()
           // create error string
           if (last_error == 0) last_error = new CHAR[128];
           // report error
-          sprintf(last_error, "chunk with index %u of %u is corrupt", current_chunk, tabled_chunks);
+          snprintf(last_error, 128, "chunk with index %u of %u is corrupt", current_chunk, tabled_chunks);
           return FALSE;
         }
       }
@@ -609,12 +609,12 @@ BOOL LASreadPoint::read_chunk_table()
       // create error string
       if (last_error == 0) last_error = new CHAR[128];
       // report error
-      sprintf(last_error, "compressor was interrupted before writing adaptive chunk table of LAZ file");
+      snprintf(last_error, 128, "compressor was interrupted before writing adaptive chunk table of LAZ file");
       return FALSE;
     }
     // otherwise we build the chunk table as we read the file
     number_chunks = 256;
-    chunk_starts = (I64*)malloc(sizeof(I64)*(number_chunks+1));
+    chunk_starts = (I64*)malloc_las(sizeof(I64) * (number_chunks + 1));
     if (chunk_starts == 0)
     {
       return FALSE;
@@ -624,7 +624,7 @@ BOOL LASreadPoint::read_chunk_table()
     // create warning string
     if (last_warning == 0) last_warning = new CHAR[128];
     // report warning
-    sprintf(last_warning, "compressor was interrupted before writing chunk table of LAZ file");
+    snprintf(last_warning, 128, "compressor was interrupted before writing chunk table of LAZ file");
     return TRUE;
   }
 
@@ -687,7 +687,7 @@ BOOL LASreadPoint::read_chunk_table()
       }
       chunk_totals[0] = 0;
     }
-    chunk_starts = (I64*)malloc(sizeof(I64)*(number_chunks+1));
+    chunk_starts = (I64*)malloc_las(sizeof(I64) * (number_chunks + 1));
     if (chunk_starts == 0)
     {
       throw 1;
@@ -733,7 +733,7 @@ BOOL LASreadPoint::read_chunk_table()
     {
       // then compressor was interrupted before getting a chance to write the chunk table
       number_chunks = 256;
-      chunk_starts = (I64*)malloc(sizeof(I64)*(number_chunks+1));
+      chunk_starts = (I64*)malloc_las(sizeof(I64) * (number_chunks + 1));
       if (chunk_starts == 0)
       {
         return FALSE;
@@ -743,12 +743,15 @@ BOOL LASreadPoint::read_chunk_table()
     }
     else
     {
+#pragma warning(push)
+#pragma warning(disable : 6011)
       // otherwise fix as many additional chunk_starts as possible
       U32 i;
       for (i = 1; i < tabled_chunks; i++)
       {
         chunk_starts[i] += chunk_starts[i-1];
       }
+#pragma warning(pop)
     }
     // create warning string
     if (last_warning == 0) last_warning = new CHAR[128];
@@ -762,17 +765,17 @@ BOOL LASreadPoint::read_chunk_table()
       // report warning
       if (last_position == chunk_table_start_position)
       {
-        sprintf(last_warning, "chunk table is missing. improper use of LAZ compressor?");
+        snprintf(last_warning, 128, "chunk table is missing. improper use of LAZ compressor?");
       }
       else
       {
-        sprintf(last_warning, "chunk table and %lld bytes are missing. LAZ file truncated during copy or transfer?", chunk_table_start_position - last_position);
+        snprintf(last_warning, 128, "chunk table and %lld bytes are missing. LAZ file truncated during copy or transfer?", chunk_table_start_position - last_position);
       }
     }
     else
     {
       // report warning
-      sprintf(last_warning, "corrupt chunk table");
+      snprintf(last_warning, 128, "corrupt chunk table");
     }
   }
   if (!instream->seek(chunks_start))
